@@ -28,7 +28,7 @@ from bottles.backend.managers.backup import BackupManager
 from bottles.backend.models.config import BottleConfig
 from bottles.backend.models.result import Result
 from bottles.backend.runner import Runner
-from bottles.backend.state import SignalManager, Signals
+from bottles.backend.state import SignalManager, Signals, TaskManager
 from bottles.backend.utils.generic import sort_by_version
 from bottles.backend.utils.manager import ManagerUtils
 from bottles.backend.utils.terminal import TerminalUtils
@@ -66,6 +66,7 @@ class BottleView(Adw.PreferencesPage):
     install_programs = Gtk.Template.Child()
     add_shortcuts = Gtk.Template.Child()
     btn_execute = Gtk.Template.Child()
+    btn_eagle = Gtk.Template.Child()
     popover_exec_settings = Gtk.Template.Child()
     exec_arguments = Gtk.Template.Child()
     exec_terminal = Gtk.Template.Child()
@@ -105,6 +106,9 @@ class BottleView(Adw.PreferencesPage):
     row_no_updates = Gtk.Template.Child()
     bottom_bar = Gtk.Template.Child()
     drop_overlay = Gtk.Template.Child()
+    box_backup_progress = Gtk.Template.Child()
+    spinner_backup = Gtk.Template.Child()
+    label_backup_progress = Gtk.Template.Child()
     # endregion
 
     content = Gdk.ContentFormats.new_for_gtype(Gdk.FileList)
@@ -133,6 +137,12 @@ class BottleView(Adw.PreferencesPage):
         self._playtime_refresh_timeout_id = None
         SignalManager.connect(Signals.ProgramFinished, self._on_program_finished)
 
+        # Backup progress tracking
+        self._backup_task_id = None
+        SignalManager.connect(Signals.TaskAdded, self._on_task_added)
+        SignalManager.connect(Signals.TaskRemoved, self._on_task_removed)
+        SignalManager.connect(Signals.TaskUpdated, self._on_task_updated)
+
         self.target.connect("drop", self.on_drop)
         self.add_controller(self.target)
         self.target.connect("enter", self.on_enter)
@@ -141,6 +151,7 @@ class BottleView(Adw.PreferencesPage):
         self.add_shortcuts.connect("clicked", self.add)
         self.install_programs.connect("clicked", self.__change_page, "installers")
         self.btn_execute.connect("clicked", self.run_executable)
+        self.btn_eagle.connect("clicked", self.run_eagle)
         self.popover_exec_settings.connect("closed", self.__run_executable_with_args)
         self.row_preferences.connect("activated", self.__change_page, "preferences")
         self.row_dependencies.connect("activated", self.__change_page, "dependencies")
@@ -448,6 +459,58 @@ class BottleView(Adw.PreferencesPage):
         self._playtime_refresh_pending = True
         self._playtime_refresh_timeout_id = GLib.timeout_add(500, do_refresh)
 
+    def _on_task_added(self, data=None):
+        """Signal handler for TaskAdded events. Shows spinner if backup task starts."""
+        if not data or not data.data:
+            return
+
+        task_id = data.data
+        task = TaskManager.get(task_id)
+        if not task:
+            return
+
+        # Check if this is a backup task for our bottle
+        backup_title = _("Backup {0}").format(self.config.Name)
+        if task.title == backup_title:
+            self._backup_task_id = task_id
+            GLib.idle_add(self._show_backup_progress)
+
+    def _on_task_removed(self, data=None):
+        """Signal handler for TaskRemoved events. Hides spinner if backup task."""
+        if not data or not data.data:
+            return
+
+        task_id = data.data
+        if task_id == self._backup_task_id:
+            self._backup_task_id = None
+            GLib.idle_add(self._hide_backup_progress)
+
+    def _on_task_updated(self, data=None):
+        """Signal handler for TaskUpdated events. Updates progress label."""
+        if not data or not data.data:
+            return
+
+        task_id = data.data
+        if task_id == self._backup_task_id:
+            task = TaskManager.get(task_id)
+            if task and task.subtitle:
+                GLib.idle_add(self._update_backup_progress, task.subtitle)
+
+    def _show_backup_progress(self):
+        """Show the backup progress indicator."""
+        self.label_backup_progress.set_text("")
+        self.box_backup_progress.set_visible(True)
+        self.spinner_backup.start()
+
+    def _hide_backup_progress(self):
+        """Hide the backup progress indicator."""
+        self.spinner_backup.stop()
+        self.box_backup_progress.set_visible(False)
+
+    def _update_backup_progress(self, text: str):
+        """Update the backup progress label."""
+        self.label_backup_progress.set_text(text)
+
     def populate_updates(self):
         for row in self.__update_rows:
             self.group_updates.remove(row)
@@ -798,8 +861,7 @@ class BottleView(Adw.PreferencesPage):
                     self.config,
                     exec_path=dialog.get_file().get_path(),
                     args=self.config.get("session_arguments"),
-                    terminal=self.config.get("run_in_terminal"),
-                    program_winebridge=self.exec_winebridge.get_active(),
+                    terminal=self.config.run_in_terminal,
                 )
 
                 def callback(a, b):
@@ -817,9 +879,12 @@ class BottleView(Adw.PreferencesPage):
             add_executable_filters(dialog)
             add_all_filters(dialog)
             dialog.set_modal(True)
+            dialog.set_current_folder(
+                Gio.File.new_for_path(ManagerUtils.get_bottle_path(self.config))
+            )
             dialog.connect("response", execute)
             dialog.show()
-            
+
         if self.window.settings.get_boolean("show-sandbox-warning"):
             dialog = Adw.MessageDialog.new(
                 self.window,
@@ -829,11 +894,40 @@ class BottleView(Adw.PreferencesPage):
                 ),
             )
             dialog.add_response("dismiss", _("_Dismiss"))
-            dialog.connect("response", show_chooser)
+            dialog.connect("response", lambda *args: show_chooser())
             dialog.present()
         else:
             show_chooser()
 
+    def run_eagle(self, _widget):
+        """
+        Pops up a dialog to select an executable for Eagle analysis.
+        """
+
+        def set_path(_dialog, response):
+            if response != Gtk.ResponseType.ACCEPT:
+                return
+
+            path = _dialog.get_file().get_path()
+            self.details.view_eagle.analyze(path)
+            self.__change_page(None, "eagle")
+
+        dialog = Gtk.FileChooserNative.new(
+            title=_("Select Executable for Eagle Analysis"),
+            action=Gtk.FileChooserAction.OPEN,
+            parent=self.window,
+            accept_label=_("Analyse"),
+        )
+
+        add_executable_filters(dialog)
+        add_all_filters(dialog)
+        dialog.set_modal(True)
+        dialog.set_current_folder(
+            Gio.File.new_for_path(ManagerUtils.get_bottle_path(self.config))
+        )
+        dialog.connect("response", set_path)
+        dialog.show()
+
     def __backup(self, widget, backup_type):
         """
         This function pop up the file chooser where the user
